# -*- coding: utf-8 -*-
###########################################################################
# Eole NG - 2007
# Copyright Pole de Competence Eole  (Ministere Education - Academie Dijon)
# Licence CeCill  cf /root/LicenceEole.txt
# eole@ac-dijon.fr
#
# config.py
#
# fichier de configuration pour la librairie SSO Eole
#
###########################################################################

import locale, os, socket

# REGLAGES DE LOCALE
# encoding = locale.getpreferredencoding() -> ne fonctionne pas toujours si le service est démarré au boot
encoding = 'UTF-8'
LC_ALL = 'fr_FR'

# VARIABLES A RENSEIGNER SI CREOLE NON DISPONIBLE
##################################################

# adresse réseau du serveur (ne pas utiliser localhost ou 127.0.0.1)
SERVER_IP_ADDR = ""
# adresse/port du serveur ldap utilisé pour l'authentification
# si non renseigné, utilisation de SERVER_IP_ADDR
LDAP_SERVER = ""
LDAP_PORT = [389]
LDAP_BASE = ["o=gouv,c=fr"]
# adresse du serveur d'authentification (nom DNS)
AUTH_SERVER_ADDR = socket.getfqdn(SERVER_IP_ADDR)
# port de la page web d'authentification
EOLESSO_PORT = '8443'
# version du protocole CAS (1 ou 2)
CAS_VERSION = 2
# URL du serveur parent si déclaré
PARENT_URL = ''
# Nom d'entité du serveur pour le protocole SAMLv2 (calculé automatiquement si chaine vide)
IDP_IDENTITY = ""
# CERTIFICAT DU SERVEUR
CERTFILE = "/etc/ssl/certs/eole.crt"
KEYFILE = "/etc/ssl/certs/eole.key"
# certificat de l'autorité de certification (pour validation des clients en mode proxy)
# si valeur vide : utilisation de ca.crt dans le même répertoire que CERTFILE
CA_LOCATION = ""
# CSS de la page de login (fichier utilisé : /usr/share/sso/interface/<nom_css>.css)
# Autre possibilité : héritage automatique ajouter theme.css
# dans /usr/share/sso/interface/theme/style/
DEFAULT_CSS = "main"
# Informations sur l'emplacement du serveur (éducation nationale)
RNE=""
ETABLISSEMENT=""

#CONSTANTES
############

# définition du délai de timeout par défaut des connexions (en secondes)
SOCK_TIMEOUT = 5.0
# durée de vie d'un login ticket : 2 heures
SESSION_TIMER = 2 * 60 * 60
# durée de vie d'un ticket d'application : 5 minutes (utilisable une seule fois)
APP_TIMER = 300
# durée de vie d'un nombre magique permettant la communication entre un frontend et un backend
# ce timeout est reinitialise a chaque fois qu'une action est lancée
MAGIC_NUMBER_TIMEOUT =  60 * 5
# durée de vie des sessions expirées. Quand une session expire, on la garde dans un cache pour savoir
# si quand une session est non valide, si elle avait expirée ou si elle n'a jamais existée
EXPIRED_SESSION_TIMEOUT = 60 * 60 * 2
# active ou non l'envoi de requêtes de logout pour les clients CAS
SEND_CAS_LOGOUT = False

# RECUPERATION DES VARIABLES DEFINIES DANS CREOLE SI DISPONIBLE
################################################################
try:
    from creole.parsedico import parse_dico
    from creole.cert import cert_file, key_file
except:
    # pas d'utilisation de la librairie creole pour le paramétrage du serveur
    # Les valeurs doivent être renseignées dans ce fichier. On affiche un message d'avertissement.
    print "Configuration Creole non disponible, utilisation des valeurs de %s" % str(__file__)
else:
    # lecture de la configuration creole du serveur (config.eol)
    # Les valeurs trouvées sont prioritaires sur les valeurs
    # définies manuellement dans ce fichier
    dico = parse_dico()
    if dico.get('adresse_ip_eth0', ''):
        SERVER_IP_ADDR = dico['adresse_ip_eth0']
    # configuration du serveur ldap
    if dico.get('ldap_sso', ''):
        LDAP_SERVER = dico['ldap_sso']
    elif dico.get('serveur_ldap', ''):
        LDAP_SERVER = dico['serveur_ldap']
    # identifiant rne du serveur si disponible
    if dico.get('numero_etab', ''):
        RNE = dico['numero_etab']
    if dico.get('libelle_etab', ''):
        ETABLISSEMENT = dico['libelle_etab']
    if dico.get('sso_session_timeout', ''):
        SESSION_TIMER = int(dico['sso_session_timeout'])
    if dico.get('base_ldap_sso', ''):
        LDAP_BASE = dico['base_ldap_sso']
    if dico.get('port_ldap_sso', ''):
        LDAP_PORT = dico['port_ldap_sso']
    if dico.get('cas_domainname', ''):
        AUTH_SERVER_ADDR = dico['cas_domainname']
    if dico.get('port_sso', ''):
        EOLESSO_PORT = dico['port_sso']
    if dico.get('cas_version', '') in ["1", "2"]:
        CAS_VERSION = int(dico['cas_version'])
    if dico.get('adresse_sso_parent', ''):
        PARENT_URL = 'https://%s:%s' % (dico['adresse_sso_parent'], dico['port_sso_parent'] or '8443')
    if dico.get('sso_cert', '') and os.path.isfile(dico['sso_cert']):
        CERTFILE = dico['sso_cert']
        KEYFILE = ''
    else:
        CERTFILE = cert_file
        if key_file and os.path.isfile(key_file):
            KEYFILE = key_file
    if dico.get('sso_css', ''):
        DEFAULT_CSS = dico['sso_css']
    if dico.has_key('sso_ca_location') and os.path.exists(dico['sso_ca_location']):
        CA_LOCATION = dico['sso_ca_location']

# VALEURS CALCULEES
####################

# URL de la page web d'authentification
AUTH_FORM_URL = 'https://%s:%s' % (AUTH_SERVER_ADDR, EOLESSO_PORT)
# URL du serveur d'authentification
AUTH_SERVER='https://%s:%s/xmlrpc' % (AUTH_SERVER_ADDR, EOLESSO_PORT)
IDP_IDENTITY = IDP_IDENTITY or "urn:fi:ac-dijon:et-%s:1.0" % (ETABLISSEMENT or AUTH_SERVER_ADDR)
CA_LOCATION = CA_LOCATION or os.path.join(os.path.dirname(CERTFILE), 'ca.crt')
LDAP_SERVER = LDAP_SERVER or SERVER_IP_ADDR

# REPERTOIRES DES DONNEES
##########################

# répertoire des filtres d'application
FILTER_DIR = os.path.join(os.path.dirname(__file__),'app_filters')
# répertoire des fichiers metadata pour les entités SAML
METADATA_DIR = os.path.join(os.path.dirname(__file__),'metadata')
# répertoire des définitions de jeux d'attributs
ATTR_SET_DIR = os.path.join(os.path.dirname(__file__),'attribute_sets')

